@@ -819,518 +819,7 @@ def addCurveObj(self, verboseMode: bool = True):
             print("HeatingCombRatio Curve:Linear Object has been added")
 
 
-def addDetHVACobjEp91(self, verboseMode: bool = True):
-    """Add Detailed HVAC objects for MultipleZone to work."""
-    for zn in self.zonenames_orig:
-        if 'VRF Outdoor Unit_'+zn in [i.Heat_Pump_Name
-                                            for i
-                                            in self.idf1.idfobjects
-                                            ['AirConditioner:VariableRefrigerantFlow']]:
-            if verboseMode:
-                print('VRF Outdoor Unit_'+
-                      zn+
-                      ' AirConditioner:VariableRefrigerantFlow '
-                      'Object already was in the model')
-        else:
-            self.idf1.newidfobject(
-                'AirConditioner:VariableRefrigerantFlow',
-                Heat_Pump_Name='VRF Outdoor Unit_'+zn,
-                Availability_Schedule_Name='On 24/7',
-                Gross_Rated_Total_Cooling_Capacity='autosize',
-                Gross_Rated_Cooling_COP='2',
-                Minimum_Outdoor_Temperature_in_Cooling_Mode=-6,
-                Maximum_Outdoor_Temperature_in_Cooling_Mode=43,
-                Cooling_Capacity_Ratio_Modifier_Function_of_Low_Temperature_Curve_Name=
-                'VRFCoolCapFT',
-                Cooling_Capacity_Ratio_Boundary_Curve_Name=
-                'VRFCoolCapFTBoundary',
-                Cooling_Capacity_Ratio_Modifier_Function_of_High_Temperature_Curve_Name=
-                'VRFCoolCapFTHi',
-                Cooling_Energy_Input_Ratio_Modifier_Function_of_Low_Temperature_Curve_Name=
-                'VRFCoolEIRFT',
-                Cooling_Energy_Input_Ratio_Boundary_Curve_Name=
-                'VRFCoolEIRFTBoundary',
-                Cooling_Energy_Input_Ratio_Modifier_Function_of_High_Temperature_Curve_Name=
-                'VRFCoolEIRFTHi',
-                Cooling_Energy_Input_Ratio_Modifier_Function_of_Low_PartLoad_Ratio_Curve_Name=
-                'CoolingEIRLowPLR',
-                Cooling_Energy_Input_Ratio_Modifier_Function_of_High_PartLoad_Ratio_Curve_Name=
-                'CoolingEIRHiPLR',
-                Cooling_Combination_Ratio_Correction_Factor_Curve_Name=
-                'CoolingCombRatio',
-                Cooling_PartLoad_Fraction_Correlation_Curve_Name='VRFCPLFFPLR',
-                Gross_Rated_Heating_Capacity='autosize',
-                Rated_Heating_Capacity_Sizing_Ratio=1,
-                Gross_Rated_Heating_COP=2.1,
-                Minimum_Outdoor_Temperature_in_Heating_Mode=-20,
-                Maximum_Outdoor_Temperature_in_Heating_Mode=40,
-                Heating_Capacity_Ratio_Modifier_Function_of_Low_Temperature_Curve_Name=
-                'VRFHeatCapFT',
-                Heating_Capacity_Ratio_Boundary_Curve_Name=
-                'VRFHeatCapFTBoundary',
-                Heating_Capacity_Ratio_Modifier_Function_of_High_Temperature_Curve_Name=
-                'VRFHeatCapFTHi',
-                Heating_Energy_Input_Ratio_Modifier_Function_of_Low_Temperature_Curve_Name=
-                'VRFHeatEIRFT',
-                Heating_Energy_Input_Ratio_Boundary_Curve_Name=
-                'VRFHeatEIRFTBoundary',
-                Heating_Energy_Input_Ratio_Modifier_Function_of_High_Temperature_Curve_Name=
-                'VRFHeatEIRFTHi',
-                Heating_Performance_Curve_Outdoor_Temperature_Type=
-                'WetBulbTemperature',
-                Heating_Energy_Input_Ratio_Modifier_Function_of_Low_PartLoad_Ratio_Curve_Name=
-                'HeatingEIRLowPLR',
-                Heating_Energy_Input_Ratio_Modifier_Function_of_High_PartLoad_Ratio_Curve_Name=
-                'HeatingEIRHiPLR',
-                Heating_Combination_Ratio_Correction_Factor_Curve_Name=
-                'HeatingCombRatio',
-                Heating_PartLoad_Fraction_Correlation_Curve_Name='VRFCPLFFPLR',
-                Minimum_Heat_Pump_PartLoad_Ratio=0.2,
-                Zone_Name_for_Master_Thermostat_Location='',
-                Master_Thermostat_Priority_Control_Type='LoadPriority',
-                Thermostat_Priority_Schedule_Name='',
-                Zone_Terminal_Unit_List_Name='VRF Outdoor Unit_'+
-                                             zn+
-                                             ' Zone List',
-                Heat_Pump_Waste_Heat_Recovery='Yes',
-                Equivalent_Piping_Length_used_for_Piping_Correction_Factor_in_Cooling_Mode=50,
-                Vertical_Height_used_for_Piping_Correction_Factor=15,
-                Piping_Correction_Factor_for_Length_in_Cooling_Mode_Curve_Name=
-                'CoolingLengthCorrectionFactor',
-                Piping_Correction_Factor_for_Height_in_Cooling_Mode_Coefficient=0,
-                Equivalent_Piping_Length_used_for_Piping_Correction_Factor_in_Heating_Mode=50,
-                Piping_Correction_Factor_for_Length_in_Heating_Mode_Curve_Name=
-                'VRF Piping Correction Factor for Length in Heating Mode',
-                Piping_Correction_Factor_for_Height_in_Heating_Mode_Coefficient=0,
-                Crankcase_Heater_Power_per_Compressor=15,
-                Number_of_Compressors=2,
-                Ratio_of_Compressor_Size_to_Total_Compressor_Capacity=0.5,
-                Maximum_Outdoor_DryBulb_Temperature_for_Crankcase_Heater=5,
-                Defrost_Strategy='Resistive',
-                Defrost_Control='Timed',
-                Defrost_Energy_Input_Ratio_Modifier_Function_of_Temperature_Curve_Name='',
-                Defrost_Time_Period_Fraction=0,
-                Resistive_Defrost_Heater_Capacity='autosize',
-                Maximum_Outdoor_Drybulb_Temperature_for_Defrost_Operation=5,
-                Condenser_Type='AirCooled',
-                Condenser_Inlet_Node_Name='VRF Outdoor Unit_'+
-                                          zn+
-                                          ' Outdoor Air Node',
-                Condenser_Outlet_Node_Name='',
-                Water_Condenser_Volume_Flow_Rate='autosize',
-                Evaporative_Condenser_Effectiveness=0.9,
-                Evaporative_Condenser_Air_Flow_Rate='autosize',
-                Evaporative_Condenser_Pump_Rated_Power_Consumption='autosize',
-                Supply_Water_Storage_Tank_Name='',
-                Basin_Heater_Capacity=0,
-                Basin_Heater_Setpoint_Temperature=2,
-                Basin_Heater_Operating_Schedule_Name='On 24/7',
-                Fuel_Type='Electricity',
-                Minimum_Outdoor_Temperature_in_Heat_Recovery_Mode=-10,
-                Maximum_Outdoor_Temperature_in_Heat_Recovery_Mode=40,
-                Heat_Recovery_Cooling_Capacity_Modifier_Curve_Name=
-                'VRF Heat Recovery Cooling Capacity Modifier',
-                Initial_Heat_Recovery_Cooling_Capacity_Fraction=0.5,
-                Heat_Recovery_Cooling_Capacity_Time_Constant=0.15,
-                Heat_Recovery_Cooling_Energy_Modifier_Curve_Name=
-                'VRF Heat Recovery Cooling Energy Modifier',
-                Initial_Heat_Recovery_Cooling_Energy_Fraction=1,
-                Heat_Recovery_Cooling_Energy_Time_Constant=0,
-                Heat_Recovery_Heating_Capacity_Modifier_Curve_Name=
-                'VRF Heat Recovery Heating Capacity Modifier',
-                Initial_Heat_Recovery_Heating_Capacity_Fraction=1,
-                Heat_Recovery_Heating_Capacity_Time_Constant=0.15,
-                Heat_Recovery_Heating_Energy_Modifier_Curve_Name=
-                'VRF Heat Recovery Heating Energy Modifier',
-                Initial_Heat_Recovery_Heating_Energy_Fraction=1,
-                Heat_Recovery_Heating_Energy_Time_Constant=0
-                )
-            if verboseMode:
-                print('VRF Outdoor Unit_'+
-                      zn+
-                      ' AirConditioner:VariableRefrigerantFlow '
-                      'Object has been added')
-
-    outdoorairnodelistlist = [i
-                              for i
-                              in self.idf1.idfobjects['OutdoorAir:NodeList']]
-    # print(outdoorairnodelistlist)
-
-    for i in range(len(outdoorairnodelistlist)):
-        firstOANL = self.idf1.idfobjects['OutdoorAir:NodeList'][-1]
-        self.idf1.removeidfobject(firstOANL)
-
-    del outdoorairnodelistlist
-
-    zoneterminalunitlistlist = [i
-                                for i
-                                in self.idf1.idfobjects['ZoneTerminalUnitList']]
-    # print(zoneterminalunitlistlist)
-
-    for i in range(len(zoneterminalunitlistlist)):
-        firstZTUL = self.idf1.idfobjects['ZoneTerminalUnitList'][-1]
-        self.idf1.removeidfobject(firstZTUL)
-
-    del zoneterminalunitlistlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'OutdoorAir:NodeList',
-            Node_or_NodeList_Name_1='VRF Outdoor Unit_'+
-                                    zn+
-                                    ' Outdoor Air Node'
-            )
-        if verboseMode:
-            print('VRF Outdoor Unit_'+
-                  zn+' Outdoor Air Node Object has been added')
-
-        self.idf1.newidfobject(
-            'ZoneTerminalUnitList',
-            Zone_Terminal_Unit_List_Name='VRF Outdoor Unit_'+
-                                         zn+
-                                         ' Zone List',
-            Zone_Terminal_Unit_Name_1=zn+' VRF Indoor Unit'
-            )
-        if verboseMode:
-            print('VRF Outdoor Unit_'+
-                  zn+
-                  ' Zone List Object has been added')
-
-    ZCTlist = [i
-               for i
-               in self.idf1.idfobjects['ZoneControl:Thermostat']]
-    # print(ZCTlist)
-
-    for i in range(len(ZCTlist)):
-        firstZCT = self.idf1.idfobjects['ZoneControl:Thermostat'][-1]
-        self.idf1.removeidfobject(firstZCT)
-
-    del ZCTlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'ZoneControl:Thermostat',
-            Name=zn+' Thermostat',
-            Zone_or_ZoneList_Name=zn,
-            Control_Type_Schedule_Name='Control type schedule: Always 4',
-            Control_1_Object_Type='ThermostatSetpoint:DualSetpoint',
-            Control_1_Name=zn+' Dual SP'
-            )
-    sizingzonelist = [i for i in self.idf1.idfobjects['Sizing:Zone']]
-    # print(sizingzonelist)
-
-    for i in range(len(sizingzonelist)):
-        firstsizingzone = self.idf1.idfobjects['Sizing:Zone'][-1]
-        self.idf1.removeidfobject(firstsizingzone)
-
-    del sizingzonelist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'Sizing:Zone',
-            Zone_or_ZoneList_Name=zn,
-            Zone_Cooling_Design_Supply_Air_Temperature_Input_Method=
-            'SupplyAirTemperature',
-            Zone_Cooling_Design_Supply_Air_Temperature=14,
-            Zone_Cooling_Design_Supply_Air_Temperature_Difference=5,
-            Zone_Heating_Design_Supply_Air_Temperature_Input_Method=
-            'SupplyAirTemperature',
-            Zone_Heating_Design_Supply_Air_Temperature=50,
-            Zone_Heating_Design_Supply_Air_Temperature_Difference=15,
-            Zone_Cooling_Design_Supply_Air_Humidity_Ratio=0.009,
-            Zone_Heating_Design_Supply_Air_Humidity_Ratio=0.004,
-            Design_Specification_Outdoor_Air_Object_Name=
-            zn+
-            ' Design Specification Outdoor Air Object',
-            Zone_Heating_Sizing_Factor=1.25,
-            Zone_Cooling_Sizing_Factor=1.15,
-            Cooling_Design_Air_Flow_Method='DesignDay',
-            Cooling_Design_Air_Flow_Rate=0,
-            Cooling_Minimum_Air_Flow_per_Zone_Floor_Area=0.00076,
-            Cooling_Minimum_Air_Flow=0,
-            Cooling_Minimum_Air_Flow_Fraction=0,
-            Heating_Design_Air_Flow_Method='DesignDay',
-            Heating_Design_Air_Flow_Rate=0,
-            Heating_Maximum_Air_Flow_per_Zone_Floor_Area=0.00203,
-            Heating_Maximum_Air_Flow=0.14158,
-            Heating_Maximum_Air_Flow_Fraction=0.3,
-            Design_Specification_Zone_Air_Distribution_Object_Name=
-            zn+' Design Specification Zone Air Distribution Object',
-            Account_for_Dedicated_Outdoor_Air_System='Yes',
-            Dedicated_Outdoor_Air_System_Control_Strategy='NeutralSupplyAir',
-            Dedicated_Outdoor_Air_Low_Setpoint_Temperature_for_Design='autosize',
-            Dedicated_Outdoor_Air_High_Setpoint_Temperature_for_Design='autosize'
-            )
-        if verboseMode:
-            print(zn+' Sizing:Zone Object has been added')
-
-    DSOAlist = [i
-                for i
-                in self.idf1.idfobjects['DesignSpecification:OutdoorAir']]
-    # print(DSOAlist)
-
-    for i in range(len(DSOAlist)):
-        firstDSOA = self.idf1.idfobjects['DesignSpecification:OutdoorAir'][-1]
-        self.idf1.removeidfobject(firstDSOA)
-
-    del DSOAlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'DesignSpecification:OutdoorAir',
-            Name=zn+' Design Specification Outdoor Air Object',
-            Outdoor_Air_Method='Flow/Person',
-            Outdoor_Air_Flow_per_Person=0.00944,
-            Outdoor_Air_Flow_per_Zone_Floor_Area=0,
-            Outdoor_Air_Flow_per_Zone=0,
-            Outdoor_Air_Flow_Air_Changes_per_Hour=0,
-            Outdoor_Air_Schedule_Name='On 24/7'
-            )
-        if verboseMode:
-            print(zn+
-                  ' Design Specification Outdoor Air Object has been added')
-
-    DSOADlist = [i
-                 for i
-                 in self.idf1.idfobjects
-                 ['DesignSpecification:ZoneAirDistribution']]
-    # print(DSOADlist)
-
-    for i in range(len(DSOADlist)):
-        firstDSZAD = self.idf1.idfobjects[
-            'DesignSpecification:ZoneAirDistribution'
-        ][-1]
-        self.idf1.removeidfobject(firstDSZAD)
-
-    del DSOADlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'DesignSpecification:ZoneAirDistribution',
-            Name=zn+' Design Specification Zone Air Distribution Object',
-            Zone_Air_Distribution_Effectiveness_in_Cooling_Mode=1,
-            Zone_Air_Distribution_Effectiveness_in_Heating_Mode=1,
-            Zone_Air_Distribution_Effectiveness_Schedule_Name='',
-            Zone_Secondary_Recirculation_Fraction=0
-            )
-        if verboseMode:
-            print(zn+
-                  ' Design Specification Zone Air Distribution '
-                  'Object has been added')
-
-    nodelistlist = [i for i in self.idf1.idfobjects['NodeList']]
-    # print(nodelistlist)
-
-    for i in range(len(nodelistlist)):
-        firstnodelist = self.idf1.idfobjects['NodeList'][-1]
-        self.idf1.removeidfobject(firstnodelist)
-
-    del nodelistlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'NodeList',
-            Name=zn+' Air Inlet Node List',
-            Node_1_Name=zn+' VRF Indoor Unit Supply Outlet'
-            )
-        self.idf1.newidfobject(
-            'NodeList',
-            Name=zn+' Air Exhaust Node List',
-            Node_1_Name=zn+' VRF Indoor Unit Return'
-            )
-        if verboseMode:
-            print(zn+' Nodelist Objects has been added')
-
-    ZHEClist = [i
-                for i
-                in self.idf1.idfobjects['ZoneHVAC:EquipmentConnections']]
-    # print(ZHEClist)
-
-    for i in range(len(ZHEClist)):
-        firstZHEC = self.idf1.idfobjects['ZoneHVAC:EquipmentConnections'][-1]
-        self.idf1.removeidfobject(firstZHEC)
-
-    del ZHEClist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'ZoneHVAC:EquipmentConnections',
-            Zone_Name=zn,
-            Zone_Conditioning_Equipment_List_Name=zn+' Equipment',
-            Zone_Air_Inlet_Node_or_NodeList_Name=zn+' Air Inlet Node List',
-            Zone_Air_Exhaust_Node_or_NodeList_Name=zn+' Air Exhaust Node List',
-            Zone_Air_Node_Name=zn+' Zone Air Node',
-            Zone_Return_Air_Node_or_NodeList_Name=zn+' Return Outlet'
-            )
-        if verboseMode:
-            print(zn+' ZoneHVAC:EquipmentConnections Objects has been added')
-
-    ZHELlist = [i for i in self.idf1.idfobjects['ZoneHVAC:EquipmentList']]
-    # print(ZHELlist)
-
-    for i in range(len(ZHELlist)):
-        firstZHEL = self.idf1.idfobjects['ZoneHVAC:EquipmentList'][-1]
-        self.idf1.removeidfobject(firstZHEL)
-
-    del ZHELlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'ZoneHVAC:EquipmentList',
-            defaultvalues=False,
-            Name=zn+' Equipment',
-            Load_Distribution_Scheme='SequentialLoad',
-            Zone_Equipment_1_Object_Type=
-            'ZoneHVAC:TerminalUnit:VariableRefrigerantFlow',
-            Zone_Equipment_1_Name=zn+' VRF Indoor Unit',
-            Zone_Equipment_1_Cooling_Sequence=1,
-            Zone_Equipment_1_Heating_or_NoLoad_Sequence=1,
-            Zone_Equipment_1_Sequential_Cooling_Fraction='',
-            Zone_Equipment_1_Sequential_Heating_Fraction=''
-            )
-        if verboseMode:
-            print(zn+' ZoneHVAC:EquipmentList Objects has been added')
-
-    ZHTUVRFlist = [i for i in self.idf1.idfobjects[
-        'ZoneHVAC:TerminalUnit:VariableRefrigerantFlow'
-    ]]
-    # print(ZHTUVRFlist)
-
-    for i in range(len(ZHTUVRFlist)):
-        firstZHTUVRF = self.idf1.idfobjects[
-            'ZoneHVAC:TerminalUnit:VariableRefrigerantFlow'
-        ][-1]
-        self.idf1.removeidfobject(firstZHTUVRF)
-
-    del ZHTUVRFlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'ZoneHVAC:TerminalUnit:VariableRefrigerantFlow',
-            Zone_Terminal_Unit_Name=zn+' VRF Indoor Unit',
-            Terminal_Unit_Availability_Schedule='On 24/7',
-            Terminal_Unit_Air_Inlet_Node_Name=zn+' VRF Indoor Unit Return',
-            Terminal_Unit_Air_Outlet_Node_Name=
-            zn+' VRF Indoor Unit Supply Outlet',
-            Cooling_Supply_Air_Flow_Rate='autosize',
-            No_Cooling_Supply_Air_Flow_Rate='autosize',
-            Heating_Supply_Air_Flow_Rate='autosize',
-            No_Heating_Supply_Air_Flow_Rate='autosize',
-            Cooling_Outdoor_Air_Flow_Rate=0,
-            Heating_Outdoor_Air_Flow_Rate=0,
-            No_Load_Outdoor_Air_Flow_Rate=0,
-            Supply_Air_Fan_Operating_Mode_Schedule_Name='On 24/7',
-            Supply_Air_Fan_Placement='DrawThrough',
-            Supply_Air_Fan_Object_Type='Fan:ConstantVolume',
-            Supply_Air_Fan_Object_Name=zn+' VRF Indoor Unit Supply Fan',
-            Outside_Air_Mixer_Object_Type='',
-            Outside_Air_Mixer_Object_Name='',
-            Cooling_Coil_Object_Type='Coil:Cooling:DX:VariableRefrigerantFlow',
-            Cooling_Coil_Object_Name=zn+' VRF Indoor Unit DX Cooling Coil',
-            Heating_Coil_Object_Type='Coil:Heating:DX:VariableRefrigerantFlow',
-            Heating_Coil_Object_Name=zn+' VRF Indoor Unit DX Heating Coil',
-            Zone_Terminal_Unit_On_Parasitic_Electric_Energy_Use=30,
-            Zone_Terminal_Unit_Off_Parasitic_Electric_Energy_Use=20,
-            Rated_Heating_Capacity_Sizing_Ratio='',
-            Availability_Manager_List_Name=''
-            )
-        if verboseMode:
-            print(zn+' ZoneHVAC:TerminalUnit:VariableRefrigerantFlow '
-                     'Object has been added')
-
-    CCDXVRFlist = [i
-                   for i
-                   in self.idf1.idfobjects
-                   ['Coil:Cooling:DX:VariableRefrigerantFlow']]
-    # print(CCDXVRFlist)
-
-    for i in range(len(CCDXVRFlist)):
-        firstCCDXVRF = self.idf1.idfobjects[
-            'Coil:Cooling:DX:VariableRefrigerantFlow'
-        ][-1]
-        self.idf1.removeidfobject(firstCCDXVRF)
-
-    del CCDXVRFlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'Coil:Cooling:DX:VariableRefrigerantFlow',
-            Name=zn+' VRF Indoor Unit DX Cooling Coil',
-            Availability_Schedule_Name='On 24/7',
-            Gross_Rated_Total_Cooling_Capacity='autosize',
-            Gross_Rated_Sensible_Heat_Ratio='autosize',
-            Rated_Air_Flow_Rate='autosize',
-            Cooling_Capacity_Ratio_Modifier_Function_of_Temperature_Curve_Name=
-            'VRFTUCoolCapFT',
-            Cooling_Capacity_Modifier_Curve_Function_of_Flow_Fraction_Name=
-            'VRFACCoolCapFFF',
-            Coil_Air_Inlet_Node=zn+' VRF Indoor Unit Return',
-            Coil_Air_Outlet_Node=zn+' VRF Indoor Unit DX Cooling Coil Outlet',
-            Name_of_Water_Storage_Tank_for_Condensate_Collection=''
-            )
-        if verboseMode:
-            print(zn+' Coil:Cooling:DX:VariableRefrigerantFlow '
-                     'Object has been added')
-
-    CHDXVRFlist = [i
-                   for i
-                   in self.idf1.idfobjects
-                   ['Coil:Heating:DX:VariableRefrigerantFlow']]
-    # print(CHDXVRFlist)
-
-    for i in range(len(CHDXVRFlist)):
-        firstCHDXVRF = self.idf1.idfobjects[
-            'Coil:Heating:DX:VariableRefrigerantFlow'
-        ][-1]
-        self.idf1.removeidfobject(firstCHDXVRF)
-
-    del CHDXVRFlist
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'Coil:Heating:DX:VariableRefrigerantFlow',
-            Name=zn+' VRF Indoor Unit DX Heating Coil',
-            Availability_Schedule='On 24/7',
-            Gross_Rated_Heating_Capacity='autosize',
-            Rated_Air_Flow_Rate='autosize',
-            Coil_Air_Inlet_Node=zn+' VRF Indoor Unit DX Cooling Coil Outlet',
-            Coil_Air_Outlet_Node=zn+' VRF Indoor Unit DX Heating Coil Outlet',
-            Heating_Capacity_Ratio_Modifier_Function_of_Temperature_Curve_Name=
-            'VRFTUHeatCapFT',
-            Heating_Capacity_Modifier_Function_of_Flow_Fraction_Curve_Name=
-            'VRFACCoolCapFFF'
-            )
-        if verboseMode:
-            print(zn+' Coil:Heating:DX:VariableRefrigerantFlow '
-                     'Object has been added')
-
-    FCVlist = [i for i in self.idf1.idfobjects['Fan:ConstantVolume']]
-    # print(FCVlist)
-
-    for i in range(len(FCVlist)):
-        firstFCV = self.idf1.idfobjects['Fan:ConstantVolume'][-1]
-        self.idf1.removeidfobject(firstFCV)
-
-    del FCVlist
-
-    for zn in self.zonenames_orig:
-        self.idf1.newidfobject(
-            'Fan:ConstantVolume',
-            Name=zn+' VRF Indoor Unit Supply Fan',
-            Availability_Schedule_Name='On 24/7',
-            Fan_Total_Efficiency=0.7,
-            Pressure_Rise=100,
-            Maximum_Flow_Rate='autosize',
-            Motor_Efficiency=0.9,
-            Motor_In_Airstream_Fraction=1,
-            Air_Inlet_Node_Name=zn+' VRF Indoor Unit DX Heating Coil Outlet',
-            Air_Outlet_Node_Name=zn+' VRF Indoor Unit Supply Outlet',
-            EndUse_Subcategory='General'
-            )
-        if verboseMode:
-            print(zn+' Fan:ConstantVolume Object has been added')
-
-
-def addDetHVACobjEp94(self, verboseMode: bool = True):
+def addDetHVACobj(self, verboseMode: bool = True):
     """Add Detailed HVAC objects for MultipleZone to work."""
     for zn in self.zonenames_orig:
         if 'VRF Outdoor Unit_'+zn in [i.Heat_Pump_Name
