@@ -30,12 +30,17 @@ def addAccis(
         'mz', or 'SingleZone' or 'sz'.
     :param Outputs: The default is 'Standard'. Can be 'Standard',
         'Simplified' or 'Timestep'.
-    :param EnergyPlus_version: The default is 'Ep94'. Can be 'Ep91' or 'Ep94'.
-    :param AdapStand: The default is None.(0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55)
-    :param CAT: The default is None.(1 = CAT I; 2 = CAT II; 3 = CAT III; 80 = 80% ACCEPT; 90 = 90% ACCEPT)
-    :param ComfMod: The default is None.(0 = Static; 1 = OUT-CTE; 2 = OUT-SEN16798/SASHRAE55; 3 = OUT-AEN16798/AASHRAE55)
-    :param HVACmode: The default is None.(0 = Fully Air-conditioned; 1 = Naturally ventilated; 2 = Mixed Mode)
-    :param VentCtrl: (0 = Ventilates above neutral temperature; 1 = Ventilates above upper comfort limit)
+    :param EnergyPlus_version: The default is 'Ep95'. Can be 'Ep91' or 'Ep95'.
+    :param AdapStand: The default is None.
+    (0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55)
+    :param CAT: The default is None.
+    (1 = CAT I; 2 = CAT II; 3 = CAT III; 80 = 80% ACCEPT; 90 = 90% ACCEPT)
+    :param ComfMod: The default is None.
+    (0 = Static; 1 = OUT-CTE; 2 = OUT-SEN16798/SASHRAE55; 3 = OUT-AEN16798/AASHRAE55)
+    :param HVACmode: The default is None.
+    (0 = Fully Air-conditioned; 1 = Naturally ventilated; 2 = Mixed Mode)
+    :param VentCtrl:
+    (0 = Ventilates above neutral temperature; 1 = Ventilates above upper comfort limit)
     :param VSToffset: Please refer to documentation.
     :param MinOToffset: Please refer to documentation.
     :param MaxWindSpeed: Please refer to documentation.
@@ -48,8 +53,8 @@ def addAccis(
 
     Exceptions
             DESCRIPTION. EnergyPlus version not supported.
-        Only works for EnergyPlus 9.1 (enter Ep91) and
-        EnergyPlus 9.4 (enter Ep94) versions.
+        Only works for versions between EnergyPlus 9.1 (enter Ep91) and
+        EnergyPlus 9.5 (enter Ep95).
 
     :return:
     """
@@ -87,8 +92,14 @@ def addAccis(
     fullEPversionsList = [
         'Ep91',
         'ep91',
+        'Ep92',
+        'ep92',
+        'Ep93',
+        'ep93',
         'Ep94',
-        'ep94'
+        'ep94',
+        'Ep95',
+        'ep95'
     ]
 
     if all(objArgsDef):
@@ -103,10 +114,10 @@ def addAccis(
         while Outputs not in fullOutputsList:
             Outputs = input("Output was not correct. "
                             "Please, enter the Output (Standard, Simplified or Timestep): ")
-        EnergyPlus_version = input("Enter the EnergyPlus version (Ep91 or Ep94): ")
+        EnergyPlus_version = input("Enter the EnergyPlus version (Ep91 to Ep95): ")
         while EnergyPlus_version not in fullEPversionsList:
             EnergyPlus_version = input("EnergyPlus version was not correct. "
-                                       "Please, enter the EnergyPlus version (Ep91 or Ep94): ")
+                                       "Please, enter the EnergyPlus version (Ep91 to Ep95): ")
     if verboseMode:
         print('ScriptType is: '+ScriptType)
     if ScriptType not in fullScriptTypeList:
@@ -135,7 +146,12 @@ def addAccis(
             print('''\n=======================START OF PROCESS=======================\n''')
             print('Starting with file:')
             print(file)
-        z = accim_Main.accimJob(filename_temp=file, ScriptType=ScriptType, EnergyPlus_version=EnergyPlus_version, verboseMode=verboseMode)
+        z = accim_Main.accimJob(
+            filename_temp=file,
+            ScriptType=ScriptType,
+            EnergyPlus_version=EnergyPlus_version,
+            verboseMode=verboseMode
+        )
 
         z.setComfFieldsPeople(verboseMode=verboseMode)
         z.addOpTempTherm(verboseMode=verboseMode)
@@ -145,10 +161,7 @@ def addAccis(
         if ScriptType.lower() == 'MultipleZones'.lower() or ScriptType.lower() == 'mz':
             z.addMultipleZoneSch(verboseMode=verboseMode)
             z.addCurveObj(verboseMode=verboseMode)
-            if EnergyPlus_version.lower() == 'ep94':
-                z.addDetHVACobjEp94(verboseMode=verboseMode)
-            elif EnergyPlus_version.lower() == 'ep91':
-                z.addDetHVACobjEp91(verboseMode=verboseMode)
+            z.addDetHVACobj(verboseMode=verboseMode)
             z.checkVentIsOn(verboseMode=verboseMode)
             z.addForscriptSchMultipleZone(verboseMode=verboseMode)
         elif ScriptType.lower() == 'SingleZone'.lower() or ScriptType.lower() == 'sz':
@@ -190,20 +203,6 @@ def addAccis(
             print(file)
             print('''\n=======================END OF PROCESS=======================\n''')
 
-    # arguments = (
-    #     AdapStand is None,
-    #     CAT is None,
-    #     ComfMod is None,
-    #     HVACmode is None,
-    #     VentCtrl is None,
-    #     VSToffset == [0],
-    #     MinOToffset == [50],
-    #     MaxWindSpeed == [50],
-    #     ASTtol_start == 0.1,
-    #     ASTtol_end_input == 0.1,
-    #     ASTtol_steps == 0.1
-    #     )
-
     args_needed_mz = (
         AdapStand is not None,
         CAT is not None,
